@@ -347,6 +347,8 @@ struct _GstFreeverbPrivate
 G_DEFINE_TYPE_WITH_CODE (GstFreeverb, gst_freeverb, GST_TYPE_BASE_TRANSFORM,
     G_ADD_PRIVATE (GstFreeverb)
     G_IMPLEMENT_INTERFACE (GST_TYPE_PRESET, NULL));
+GST_ELEMENT_REGISTER_DEFINE (freeverb, "freeverb",
+    GST_RANK_NONE, GST_TYPE_FREEVERB);
 
 static void
 freeverb_revmodel_init (GstFreeverb * filter)
@@ -928,8 +930,7 @@ gst_freeverb_transform (GstBaseTransform * base, GstBuffer * inbuf,
 static gboolean
 plugin_init (GstPlugin * plugin)
 {
-  return gst_element_register (plugin, "freeverb",
-      GST_RANK_NONE, GST_TYPE_FREEVERB);
+  return GST_ELEMENT_REGISTER (freeverb, plugin);
 }
 
 GST_PLUGIN_DEFINE (GST_VERSION_MAJOR,
